==> makoureactor_1.7.1-0~343~ubuntu15.04.1.tar.xz: makoureactor-1.7.1/widgets/MassImportDialog.h <==
/****************************************************************************
 ** Makou Reactor Final Fantasy VII Field Script Editor
 ** Copyright (C) 2009-2012 Arzel Jérôme <myst6re@gmail.com>
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
#ifndef MASSIMPORTDIALOG_H
#define MASSIMPORTDIALOG_H

#include <QtWidgets>
#include "core/field/FieldArchive.h"
#include "FormatSelectionWidget.h"

class MassImportDialog : public QDialog
{
	Q_OBJECT
public:
	enum ImportType {
		Fields, Akaos, Texts
	};

	explicit MassImportDialog(QWidget *parent = 0);
	void fill(const FieldArchive *fieldArchive, int currentField);
	QList<int> selectedFields() const;
	bool importModule(ImportType type) const;
	const QString &moduleFormat(ImportType type) const;
	QString directory() const;
private slots:
	void chooseImportDirectory();
	void selectCurrentField();
private:
	QListWidget *fieldList;
	QMap<ImportType, FormatSelectionWidget *> imports;
	QLineEdit *dirPath;
	QPushButton *changeDir;

	const FieldArchive *_fieldArchive;
	int _currentField;
protected:
	void accept();
};

#endif // MASSIMPORTDIALOG_H

==> makoureactor_1.8.0-0~431~ubuntu16.04.1.tar.xz: makoureactor-1.8.0/widgets/MassImportDialog.h <==
/****************************************************************************
 ** Makou Reactor Final Fantasy VII Field Script Editor
 ** Copyright (C) 2009-2012 Arzel Jérôme <myst6re@gmail.com>
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
#ifndef MASSIMPORTDIALOG_H
#define MASSIMPORTDIALOG_H

#include <QtWidgets>
#include "core/field/FieldArchive.h"
#include "FormatSelectionWidget.h"

class MassImportDialog : public QDialog
{
	Q_OBJECT
public:
	enum ImportType {
		Fields, Akaos, Texts
	};

	explicit MassImportDialog(QWidget *parent = 0);
	void fill(const FieldArchive *fieldArchive, int currentMapId);
	QList<int> selectedFields() const;
	bool importModule(ImportType type) const;
	const QString &moduleFormat(ImportType type) const;
	QString directory() const;
private slots:
	void chooseImportDirectory();
	void selectCurrentField();
private:
	QListWidget *fieldList;
	QMap<ImportType, FormatSelectionWidget *> imports;
	QLineEdit *dirPath;
	QPushButton *changeDir;

	const FieldArchive *_fieldArchive;
	int _currentMapId;
protected:
	void accept();
};

#endif // MASSIMPORTDIALOG_H
